@@ -2,7 +2,7 @@ lassoSML <-
 function(Y,X,Missing,B,Verbose = 5){
 	M = nrow(Y);
 	N = ncol(Y);
-	cat("\tLASSO SML version_1;",M, "Genes, ", N , "samples; Verbose: ", Verbose, "\n\n")
+	if(Verbose>=0) cat("\tLASSO SML version_1;",M, "Genes, ", N , "samples; Verbose: ", Verbose, "\n\n")
 	f = matrix(1,M,1);
 	stat = rep(0,6);
 
@@ -23,7 +23,7 @@ function(Y,X,Missing,B,Verbose = 5){
 	tEnd = proc.time();
 	simTime = tEnd - tStart;
 	#dyn.unload("lassoSMLv9beta.dll")
-	cat("\t computation time:", simTime[1], "sec\n");
+	if(Verbose>=0) cat("\t computation time:", simTime[1], "sec\n");
 
 	Bout = matrix(output$B,nrow= M, ncol = M, byrow = F);
 	fout = matrix(output$f,nrow= M, ncol = 1, byrow = F);
